/****************************************************************************************
|  Description: Pushbutton driver source file
|    File Name: button.c
|
|----------------------------------------------------------------------------------------
|                          C O P Y R I G H T
|----------------------------------------------------------------------------------------
|     Copyright (c) 2012 by Feaser     http://www.feaser.com     All rights reserved
|
|   This software is the property of Feaser. The source and compiled code may only be 
|        used on the Olimex EM32G880F128-STK board (http://www.olimex.com/dev).
| 
|      This copyright notice may not be removed from the source code nor changed.
|
|   This software has been carefully tested, but is not guaranteed for any particular
| purpose. The author does not offer any warranties and does not guarantee the accuracy,
|   adequacy, or completeness of the software and is not responsible for any errors or
|              omissions or the results obtained from use of the software.
|
****************************************************************************************/

/****************************************************************************************
* Include files
****************************************************************************************/
#include "header.h"                                   /* generic header file           */
#include "efm32_gpio.h"                               /* EFM32 GPIO module             */


/****************************************************************************************
** NAME:           ButtonInit
** PARAMETER:      none
** RETURN VALUE:   none
** DESCRIPTION:    Initializes the pushbutton driver.
**
****************************************************************************************/
void ButtonInit(void)
{
  /* configure PE0, PE1, PE2, PE3 as input with pull up */
  GPIO_PinModeSet(gpioPortE, 0, gpioModeInputPullFilter, 1);
  GPIO_PinModeSet(gpioPortE, 1, gpioModeInputPullFilter, 1);
  GPIO_PinModeSet(gpioPortE, 2, gpioModeInputPullFilter, 1);
  GPIO_PinModeSet(gpioPortE, 3, gpioModeInputPullFilter, 1);
} /*** end of ButtonInit ***/


/****************************************************************************************
** NAME:           ButtonGet
** PARAMETER:      id pushbutton identifier. Can be BUT1, BUT2, BUT3 or BUT4
** RETURN VALUE:   TRUE is the button is pressed, FALSE otherwise.
** DESCRIPTION:    Obtains the status of the pushbutton.
**
****************************************************************************************/
unsigned char ButtonGet(tButtonId id)
{
  if (GPIO_PinInGet(gpioPortE, (unsigned int)id) == 0)
  {
    return TRUE;
  }
  return FALSE;
} /*** end of ButtonGet ***/


/************************************ end of button.c **********************************/


